#!/bin/bash

# Fail the whole script if one command fails.
set -e

# Get to initial state.
rm -rf empty_file_test.apk empty_file_test_rebuilt.apk assets/ apkdata/
cp deflated_unknowns.apk empty_file_test.apk

# Add empty and non-empty files.
mkdir -p assets/
dd if=/dev/zero of=assets/empty.dat bs=1M count=0  status=none
dd if=/dev/zero of=assets/big.dat   bs=1M count=10 status=none
# Ask zip to DEFLATE the added files with maximum compression.
zip --compression-method deflate -9 -r -q empty_file_test.apk assets/

echo "*** Before rebuilding:"
unzip -v empty_file_test.apk | grep dat | egrep --color=auto 'Stored|Defl:X'
echo
# Output:
# ---
# *** Before rebuilding:
#        0  Stored        0   0% 2018-07-18 15:21 00000000  assets/empty.dat
# 10485760  Defl:X    10190 100% 2018-07-18 15:21 9eca2acc  assets/big.dat
# ---
# Note that empty.dat is STORED, but big.dat is DEFLATED.

echo "*** Decoding:"
java -jar apktool-cli-all.jar d -o apkdata/ empty_file_test.apk
echo

if [ -n "`which ruby`" -a -f "print_doNotCompress_node.rb" ]; then
    echo "*** doNotCompress node from apktool.yml:"
    ruby print_doNotCompress_node.rb | egrep --context=10 --color=auto 'doNotCompress|dat'
fi
echo

echo "*** Building:"
java -jar apktool-cli-all.jar b -o empty_file_test_rebuilt.apk apkdata/
echo

echo "*** After rebuilding:"
unzip -v empty_file_test_rebuilt.apk | grep dat | egrep --color=auto 'Stored|Defl:X'
echo
# Output:
# ---
# *** After rebuilding:
#        0  Stored        0   0% 2018-07-18 15:21 00000000  assets/empty.dat
# 10485760  Stored 10485760   0% 2018-07-18 15:21 9eca2acc  assets/big.dat
# ---
# Note that all .dat files are now STORED.
